<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Arc</name>
    <message>
        <location filename="../Arc.js" line="+71"/>
        <source>Arc Tools</source>
        <translatorcomment>--google--
Pokaż menu &quot;Łuki&quot;</translatorcomment>
        <translation>Narzędzia łuku</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show arc tools</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż menu &quot;Łuki&quot;</translatorcomment>
        <translation>Wyświetla narzędzia łuku</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Arc</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
Ł&amp;uk</translatorcomment>
        <translation>Ł&amp;uk</translation>
    </message>
</context>
</TS>
